@@ -150,7 +150,12 @@ static void hddtemp_plugin_get_sensors(GList **sensors) {
 	pv = output_vector = g_strsplit(hddtemp_output, "|", -1);
 	
 	while(pv[1] != NULL) {
-		if (g_strcmp0(pv[2], "") && g_strcmp0(pv[3], "") && g_strcmp0(pv[4], "") && (!(g_ascii_strcasecmp(pv[2], "???") == 0 || g_ascii_strcasecmp(pv[3], "ERR") == 0 || g_ascii_strcasecmp(pv[4], "*") == 0))) {
+		if (g_strcmp0(pv[2], "") != 0 &&
+		    g_strcmp0(pv[3], "") != 0 &&
+		    g_strcmp0(pv[4], "") != 0 &&
+		    (!(g_ascii_strcasecmp(pv[2], "???") == 0 ||
+		       g_ascii_strcasecmp(pv[3], "ERR") == 0 ||
+		       g_ascii_strcasecmp(pv[4], "*") == 0))) {
                         sensors_applet_plugin_add_sensor(sensors,
                                                         pv[1], // must be dynamically allocated
                                                         pv[1], // must be dynamically allocated
