@@ -60,7 +60,7 @@ typedef struct {
 	GtkAlignment *alarm_timeout_spinbutton_aligner;
 	GtkAdjustment *alarm_timeout_adjust;
 	GtkSpinButton *alarm_timeout_spinbutton;
-	GtkTable *table;
+	GtkGrid *grid;
 	GtkAlignment *alarm_enable_aligner;
 	GtkCheckButton *alarm_enable_checkbutton;
 	GtkEntry *low_alarm_command_entry, *high_alarm_command_entry;
@@ -325,7 +325,6 @@ static void sensor_config_dialog_graph_color_set(GtkColorButton *color_button,
 	GtkTreeIter iter;
         GtkWidget *content_area;
         gchar *color_string;
-#if GTK_CHECK_VERSION (3, 0, 0)
         GdkRGBA color;
 
         gtk_color_button_get_rgba(color_button,
@@ -334,15 +333,6 @@ static void sensor_config_dialog_graph_color_set(GtkColorButton *color_button,
         color_string = g_strdup_printf ("#%02X%02X%02X", (int)(0.5 + CLAMP (color.red, 0., 1.) * 255.),
 					(int)(0.5 + CLAMP (color.green, 0., 1.) * 255.),
 					(int)(0.5 + CLAMP (color.blue, 0., 1.) * 255.));
-#else
-        GdkColor color;
-
-        gtk_color_button_get_color(color_button,
-                                   &color);
-
-        color_string = g_strdup_printf("#%02X%02X%02X", color.red / 256, 
-                                       color.green / 256, color.blue / 256);
-#endif
 
         gtk_tree_selection_get_selected(config_dialog->sensors_applet->selection,
 					&model,
@@ -371,12 +361,7 @@ void sensor_config_dialog_create(SensorsApplet *sensors_applet) {
         GtkListStore *icon_store;
         IconType count;
         GdkPixbuf *pixbuf;
-
-#if GTK_CHECK_VERSION (3, 0, 0)
         GdkRGBA graph_color;
-#else
-        GdkColor graph_color;        
-#endif
         gchar *sensor_label;
         gchar *header_text;
         
@@ -444,13 +429,8 @@ void sensor_config_dialog_create(SensorsApplet *sensors_applet) {
         g_free(header_text);
 
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         gdk_rgba_parse(&graph_color, graph_color_string);
         config_dialog->graph_color_button = GTK_COLOR_BUTTON(gtk_color_button_new_with_rgba(&graph_color));
-#else
-        gdk_color_parse(graph_color_string, &graph_color);
-        config_dialog->graph_color_button = GTK_COLOR_BUTTON(gtk_color_button_new_with_color(&graph_color));
-#endif
 	config_dialog->graph_color_button_aligner = g_object_new(GTK_TYPE_ALIGNMENT,
                                                   "child", config_dialog->graph_color_button,
                                                    "xalign", 0.0,
@@ -803,139 +783,113 @@ void sensor_config_dialog_create(SensorsApplet *sensors_applet) {
                                   GTK_WIDGET(config_dialog->graph_color_button));
         g_object_unref(config_dialog->size_group);
 
-	config_dialog->table = g_object_new(GTK_TYPE_TABLE,
-			     "column-spacing", 5,
-			     "homogeneous", FALSE,
-			     "n-columns", 3,
-			     "n-rows", 15,
-                             "row-spacing", 6,
-                             "column-spacing", 12,
-			     NULL);
+    config_dialog->grid = g_object_new(GTK_TYPE_GRID,
+                 "column-spacing", 5,
+                 "row-homogeneous", FALSE,
+                 "column-homogeneous", FALSE,
+                 "row-spacing", 6,
+                 "column-spacing", 12,
+                 NULL);
 
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->scale_header),
+                    0, 0, 2, 1);
 
-        gtk_table_attach_defaults(config_dialog->table,
-                                  GTK_WIDGET(config_dialog->scale_header),
-                                  0, 2,
-                                  0, 1);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->multiplier_label),
+                    1, 1, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->multiplier_label),
-				  1, 2,
-				  1, 2);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->multiplier_spinbutton_aligner),
-				  2, 3,
-				  1, 2);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->offset_label),
-				  1, 2,
-				  2, 3);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->multiplier_spinbutton_aligner),
+                    2, 1, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->offset_spinbutton_aligner),
-				  2, 3,
-				  2, 3);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->limits_header),
-				  0, 2,
-				  3, 4);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->offset_label),
+                    1, 2, 1, 1);
 
-	/* now pack alarm widgets */
-        gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->low_value_label),
-				  1, 2,
-				  4, 5);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->low_value_spinbutton_aligner),
-				  2, 3,
-				  4, 5);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->offset_spinbutton_aligner),
+                    2, 2, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->high_value_label),
-				  1, 2,
-				  5, 6);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->high_value_spinbutton_aligner),
-				  2, 3,
-				  5, 6);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->alarm_header),
-				  0, 2,
-				  6, 7);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->limits_header),
+                    0, 3, 2, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->alarm_enable_aligner),
-				  1, 2,
-				  7, 8);	
+    /* now pack alarm widgets */
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->low_value_label),
+                    1, 4, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->alarm_timeout_label),
-				  1, 2,
-				  8, 9);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->low_value_spinbutton_aligner),
+                    2, 4, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->alarm_timeout_spinbutton_aligner),
-				  2, 3,
-				  8, 9);
-	
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->low_alarm_command_label),
-				  1, 2,
-				  9, 10);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->high_value_label),
+                    1, 5, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->low_alarm_command_entry),
-				  2, 3,
-				  9, 10);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->high_value_spinbutton_aligner),
+                    2, 5, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->high_alarm_command_label),
-				  1, 2,
-				  10, 11);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->alarm_header),
+                    0, 6, 2, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->high_alarm_command_entry),
-				  2, 3,
-				  10, 11);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->alarm_enable_aligner),
+                    1, 7, 1, 1);
 
-        gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->icon_header),
-				  0, 2,
-				  11, 12);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->alarm_timeout_label),
+                    1, 8, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->icon_type_label),
-				  1, 2,
-				  12, 13);
-	
-        gtk_table_attach_defaults(config_dialog->table,
-                                  GTK_WIDGET(config_dialog->icon_type_combo_box_aligner),
-                                  2, 3,
-                                  12, 13);
-        
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->graph_header),
-				  0, 2,
-				  13, 14);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->alarm_timeout_spinbutton_aligner),
+                    2, 8, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->graph_color_label),
-				  1, 2,
-				  14, 15);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->low_alarm_command_label),
+                    1, 9, 1, 1);
 
-	gtk_table_attach_defaults(config_dialog->table,
-				  GTK_WIDGET(config_dialog->graph_color_button_aligner),
-				  2, 3,
-				  14, 15);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->low_alarm_command_entry),
+                    2, 9, 1, 1);
 
-        content_area = gtk_dialog_get_content_area (GTK_DIALOG(config_dialog->dialog));
-	gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(config_dialog->table), FALSE, FALSE, 0);
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->high_alarm_command_label),
+                    1, 10, 1, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->high_alarm_command_entry),
+                    2, 10, 1, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->icon_header),
+                    0, 11, 2, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->icon_type_label),
+                    1, 12, 1, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->icon_type_combo_box_aligner),
+                    2, 12, 1, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->graph_header),
+                    0, 13, 2, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->graph_color_label),
+                    1, 14, 1, 1);
+
+    gtk_grid_attach(config_dialog->grid,
+                    GTK_WIDGET(config_dialog->graph_color_button_aligner),
+                    2, 14, 1, 1);
+
+    content_area = gtk_dialog_get_content_area (GTK_DIALOG(config_dialog->dialog));
+    gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(config_dialog->grid), FALSE, FALSE, 0);
 	gtk_widget_show_all(config_dialog->dialog);
 
 }		
